# openapi-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.73
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import openapi_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import openapi_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import openapi_client
from pprint import pprint
from openapi_client.api import default_api
from openapi_client.model.activation_params import ActivationParams
from openapi_client.model.add_custom_loss_params import AddCustomLossParams
from openapi_client.model.add_custom_loss_response import AddCustomLossResponse
from openapi_client.model.add_dashboard_params import AddDashboardParams
from openapi_client.model.add_dataset_response import AddDatasetResponse
from openapi_client.model.add_export_model_job_params import AddExportModelJobParams
from openapi_client.model.add_job_params import AddJobParams
from openapi_client.model.add_secret_manager_params import AddSecretManagerParams
from openapi_client.model.add_secret_manager_response import AddSecretManagerResponse
from openapi_client.model.custom_loss_list_response import CustomLossListResponse
from openapi_client.model.dataset_parse_request_params import DatasetParseRequestParams
from openapi_client.model.delete_visualizations_params import DeleteVisualizationsParams
from openapi_client.model.external_import_model_storage import ExternalImportModelStorage
from openapi_client.model.external_import_model_storage_response import ExternalImportModelStorageResponse
from openapi_client.model.get_branch_versions_params import GetBranchVersionsParams
from openapi_client.model.get_branch_versions_response import GetBranchVersionsResponse
from openapi_client.model.get_bucket_list_params import GetBucketListParams
from openapi_client.model.get_bucket_list_response import GetBucketListResponse
from openapi_client.model.get_current_project_version_params import GetCurrentProjectVersionParams
from openapi_client.model.get_current_project_version_response import GetCurrentProjectVersionResponse
from openapi_client.model.get_custom_loss_version_params import GetCustomLossVersionParams
from openapi_client.model.get_custom_loss_version_response import GetCustomLossVersionResponse
from openapi_client.model.get_dashboards_response import GetDashboardsResponse
from openapi_client.model.get_dataset_version_params import GetDatasetVersionParams
from openapi_client.model.get_dataset_version_response import GetDatasetVersionResponse
from openapi_client.model.get_datasets_response import GetDatasetsResponse
from openapi_client.model.get_deleted_visualizations_params import GetDeletedVisualizationsParams
from openapi_client.model.get_deleted_visualizations_response import GetDeletedVisualizationsResponse
from openapi_client.model.get_demos_response import GetDemosResponse
from openapi_client.model.get_exported_model_jobs_params import GetExportedModelJobsParams
from openapi_client.model.get_exported_model_jobs_response import GetExportedModelJobsResponse
from openapi_client.model.get_jobs_params import GetJobsParams
from openapi_client.model.get_jobs_response import GetJobsResponse
from openapi_client.model.get_kibana_dashboards_response import GetKibanaDashboardsResponse
from openapi_client.model.get_latest_custom_loss_version_params import GetLatestCustomLossVersionParams
from openapi_client.model.get_latest_custom_loss_version_response import GetLatestCustomLossVersionResponse
from openapi_client.model.get_latest_dataset_version_params import GetLatestDatasetVersionParams
from openapi_client.model.get_latest_dataset_version_response import GetLatestDatasetVersionResponse
from openapi_client.model.get_model_jobs_params import GetModelJobsParams
from openapi_client.model.get_model_jobs_response import GetModelJobsResponse
from openapi_client.model.get_model_visualizations_params import GetModelVisualizationsParams
from openapi_client.model.get_model_visualizations_response import GetModelVisualizationsResponse
from openapi_client.model.get_notifications_response import GetNotificationsResponse
from openapi_client.model.get_organization_jobs_params import GetOrganizationJobsParams
from openapi_client.model.get_project_slim_versions_response import GetProjectSlimVersionsResponse
from openapi_client.model.get_project_versions_params import GetProjectVersionsParams
from openapi_client.model.get_project_versions_response import GetProjectVersionsResponse
from openapi_client.model.get_projects_response import GetProjectsResponse
from openapi_client.model.get_secret_manager_list_response import GetSecretManagerListResponse
from openapi_client.model.get_stored_exported_model_resource_url_params import GetStoredExportedModelResourceUrlParams
from openapi_client.model.get_stored_exported_model_resource_url_response import GetStoredExportedModelResourceUrlResponse
from openapi_client.model.get_training_job_params import GetTrainingJobParams
from openapi_client.model.get_upload_signed_url_params import GetUploadSignedUrlParams
from openapi_client.model.get_visualization_params import GetVisualizationParams
from openapi_client.model.import_demo_project_params import ImportDemoProjectParams
from openapi_client.model.import_demo_project_response import ImportDemoProjectResponse
from openapi_client.model.import_new_model_params import ImportNewModelParams
from openapi_client.model.inline_response200 import InlineResponse200
from openapi_client.model.is_training_job_running_params import IsTrainingJobRunningParams
from openapi_client.model.is_training_job_running_response import IsTrainingJobRunningResponse
from openapi_client.model.job import Job
from openapi_client.model.key_login_params import KeyLoginParams
from openapi_client.model.list_objects_params import ListObjectsParams
from openapi_client.model.list_objects_response import ListObjectsResponse
from openapi_client.model.load_model_params import LoadModelParams
from openapi_client.model.load_model_response import LoadModelResponse
from openapi_client.model.load_version_params import LoadVersionParams
from openapi_client.model.load_version_response import LoadVersionResponse
from openapi_client.model.login_params import LoginParams
from openapi_client.model.model_hash_request_params import ModelHashRequestParams
from openapi_client.model.model_version_id_request_params import ModelVersionIdRequestParams
from openapi_client.model.models_response import ModelsResponse
from openapi_client.model.new_dataset_params import NewDatasetParams
from openapi_client.model.parse_dataset_response import ParseDatasetResponse
from openapi_client.model.recent_models_response import RecentModelsResponse
from openapi_client.model.recent_organization_models_request_params import RecentOrganizationModelsRequestParams
from openapi_client.model.recover_visualizations_params import RecoverVisualizationsParams
from openapi_client.model.recover_visualizations_response import RecoverVisualizationsResponse
from openapi_client.model.remove_dashboard_params import RemoveDashboardParams
from openapi_client.model.remove_project_from_dashboard_params import RemoveProjectFromDashboardParams
from openapi_client.model.request_trial_params import RequestTrialParams
from openapi_client.model.request_trial_response import RequestTrialResponse
from openapi_client.model.resend_activation_mail_params import ResendActivationMailParams
from openapi_client.model.resend_activation_mail_response import ResendActivationMailResponse
from openapi_client.model.reset_password_params import ResetPasswordParams
from openapi_client.model.reset_password_response import ResetPasswordResponse
from openapi_client.model.save_analyzer_layout_params import SaveAnalyzerLayoutParams
from openapi_client.model.save_custom_loss_version_params import SaveCustomLossVersionParams
from openapi_client.model.save_custom_loss_version_response import SaveCustomLossVersionResponse
from openapi_client.model.save_dataset_setup_response import SaveDatasetSetupResponse
from openapi_client.model.save_dataset_version_params import SaveDatasetVersionParams
from openapi_client.model.save_project_params import SaveProjectParams
from openapi_client.model.save_project_response import SaveProjectResponse
from openapi_client.model.send_reset_password_mail_params import SendResetPasswordMailParams
from openapi_client.model.send_reset_password_mail_response import SendResetPasswordMailResponse
from openapi_client.model.set_project_to_dashboard_params import SetProjectToDashboardParams
from openapi_client.model.set_user_metadata_params import SetUserMetadataParams
from openapi_client.model.set_user_metadata_response import SetUserMetadataResponse
from openapi_client.model.signup_params import SignupParams
from openapi_client.model.signup_response import SignupResponse
from openapi_client.model.terminate_job_params import TerminateJobParams
from openapi_client.model.terminate_job_response import TerminateJobResponse
from openapi_client.model.test_custom_loss_params import TestCustomLossParams
from openapi_client.model.test_custom_loss_response import TestCustomLossResponse
from openapi_client.model.test_stub_params import TestStubParams
from openapi_client.model.test_stub_response import TestStubResponse
from openapi_client.model.trash_custom_loss_params import TrashCustomLossParams
from openapi_client.model.trash_dataset_params import TrashDatasetParams
from openapi_client.model.trash_project_params import TrashProjectParams
from openapi_client.model.trash_secret_manager_params import TrashSecretManagerParams
from openapi_client.model.trash_secret_manager_response import TrashSecretManagerResponse
from openapi_client.model.update_secret_manager_params import UpdateSecretManagerParams
from openapi_client.model.update_secret_manager_response import UpdateSecretManagerResponse
from openapi_client.model.user_data import UserData
from openapi_client.model.visualization import Visualization
# Defining the host is optional and defaults to http://localhost/api/v2
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "http://localhost/api/v2"
)



# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = default_api.DefaultApi(api_client)
    activation_params = ActivationParams(
        token="token_example",
    ) # ActivationParams | 

    try:
        api_response = api_instance.activate(activation_params)
        pprint(api_response)
    except openapi_client.ApiException as e:
        print("Exception when calling DefaultApi->activate: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/api/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**activate**](docs/DefaultApi.md#activate) | **POST** /auth/activate | 
*DefaultApi* | [**add_custom_loss**](docs/DefaultApi.md#add_custom_loss) | **POST** /custom-loss/addCustomLoss | 
*DefaultApi* | [**add_dashboard**](docs/DefaultApi.md#add_dashboard) | **POST** /dashboards/add | 
*DefaultApi* | [**add_dataset**](docs/DefaultApi.md#add_dataset) | **POST** /datasets/addDataset | 
*DefaultApi* | [**add_export_model_job**](docs/DefaultApi.md#add_export_model_job) | **POST** /jobs/addExportModelJob | 
*DefaultApi* | [**add_job**](docs/DefaultApi.md#add_job) | **POST** /jobs/addJob | 
*DefaultApi* | [**add_secret_manager**](docs/DefaultApi.md#add_secret_manager) | **POST** /secret-manager/addSecretManager | 
*DefaultApi* | [**delete_visualizations**](docs/DefaultApi.md#delete_visualizations) | **POST** /visualizations/deleteVisualizations | 
*DefaultApi* | [**get_branch_versions**](docs/DefaultApi.md#get_branch_versions) | **POST** /versions/getBranchVersions | 
*DefaultApi* | [**get_bucket_list**](docs/DefaultApi.md#get_bucket_list) | **POST** /datasets/getBucketList | 
*DefaultApi* | [**get_current_project_version**](docs/DefaultApi.md#get_current_project_version) | **POST** /projects/getCurrentProjectVersion | 
*DefaultApi* | [**get_custom_loss_version**](docs/DefaultApi.md#get_custom_loss_version) | **POST** /custom-loss/getCustomLossVersion | 
*DefaultApi* | [**get_custom_losses**](docs/DefaultApi.md#get_custom_losses) | **POST** /custom-loss/getCustomLosses | 
*DefaultApi* | [**get_dashboards**](docs/DefaultApi.md#get_dashboards) | **POST** /dashboards/list | 
*DefaultApi* | [**get_dataset_version**](docs/DefaultApi.md#get_dataset_version) | **POST** /datasets/getDatasetVersion | 
*DefaultApi* | [**get_datasets**](docs/DefaultApi.md#get_datasets) | **POST** /datasets/getDatasets | 
*DefaultApi* | [**get_deleted_visualizations**](docs/DefaultApi.md#get_deleted_visualizations) | **POST** /visualizations/getDeletedVisualizations | 
*DefaultApi* | [**get_demos**](docs/DefaultApi.md#get_demos) | **POST** /demos/getDemos | 
*DefaultApi* | [**get_exported_model_jobs**](docs/DefaultApi.md#get_exported_model_jobs) | **POST** /exportedmodels/getExportedModelJobs | 
*DefaultApi* | [**get_jobs**](docs/DefaultApi.md#get_jobs) | **POST** /jobs/getJobs | 
*DefaultApi* | [**get_kibana_dashboards**](docs/DefaultApi.md#get_kibana_dashboards) | **POST** /dashboards/getKibanaDashboards | 
*DefaultApi* | [**get_latest_custom_loss_version**](docs/DefaultApi.md#get_latest_custom_loss_version) | **POST** /custom-loss/getLatestCustomLossVersion | 
*DefaultApi* | [**get_latest_dataset_version**](docs/DefaultApi.md#get_latest_dataset_version) | **POST** /datasets/getLatestDatasetVersion | 
*DefaultApi* | [**get_model_jobs**](docs/DefaultApi.md#get_model_jobs) | **POST** /jobs/getModelJobs | 
*DefaultApi* | [**get_model_visualizations**](docs/DefaultApi.md#get_model_visualizations) | **POST** /visualizations/getModelVisualizations | 
*DefaultApi* | [**get_models_by_hash**](docs/DefaultApi.md#get_models_by_hash) | **POST** /models/getModelsByHash | 
*DefaultApi* | [**get_models_by_version_id**](docs/DefaultApi.md#get_models_by_version_id) | **POST** /models/getModelsByVersionId | 
*DefaultApi* | [**get_notifications**](docs/DefaultApi.md#get_notifications) | **POST** /notifications/getDemos | 
*DefaultApi* | [**get_organization_jobs**](docs/DefaultApi.md#get_organization_jobs) | **POST** /jobs/getOrganizationJobs | 
*DefaultApi* | [**get_project_slim_versions**](docs/DefaultApi.md#get_project_slim_versions) | **POST** /versions/getProjectSlimVersions | 
*DefaultApi* | [**get_project_versions**](docs/DefaultApi.md#get_project_versions) | **POST** /versions/getProjectVersions | 
*DefaultApi* | [**get_projects**](docs/DefaultApi.md#get_projects) | **POST** /projects/getProjects | 
*DefaultApi* | [**get_recent_organization_models**](docs/DefaultApi.md#get_recent_organization_models) | **POST** /models/getRecentOrganizationModels | 
*DefaultApi* | [**get_secret_manager_list**](docs/DefaultApi.md#get_secret_manager_list) | **POST** /secret-manager/getSecretManagerList | 
*DefaultApi* | [**get_stored_exported_model_resource_url**](docs/DefaultApi.md#get_stored_exported_model_resource_url) | **POST** /exportedmodels/getStoredExportedModelResourceUrl | 
*DefaultApi* | [**get_stored_resource**](docs/DefaultApi.md#get_stored_resource) | **GET** /jobs/getStoredResource | 
*DefaultApi* | [**get_stored_resource_string**](docs/DefaultApi.md#get_stored_resource_string) | **GET** /jobs/getStoredResourceUrl | 
*DefaultApi* | [**get_training_jobs**](docs/DefaultApi.md#get_training_jobs) | **POST** /jobs/getTrainingJobs | 
*DefaultApi* | [**get_upload_signed_url**](docs/DefaultApi.md#get_upload_signed_url) | **POST** /versions/getUploadSignedUrl | 
*DefaultApi* | [**get_visualization**](docs/DefaultApi.md#get_visualization) | **POST** /visualizations/getVisualization | 
*DefaultApi* | [**import_demo_project**](docs/DefaultApi.md#import_demo_project) | **POST** /demos/importDemoProject | 
*DefaultApi* | [**import_model**](docs/DefaultApi.md#import_model) | **POST** /versions/importModel | 
*DefaultApi* | [**is_training_job_running**](docs/DefaultApi.md#is_training_job_running) | **POST** /jobs/isTrainingJobRunning | 
*DefaultApi* | [**key_gen**](docs/DefaultApi.md#key_gen) | **POST** /auth/keygen | 
*DefaultApi* | [**key_login**](docs/DefaultApi.md#key_login) | **POST** /auth/keylogin | 
*DefaultApi* | [**load_model**](docs/DefaultApi.md#load_model) | **POST** /projects/loadModel | 
*DefaultApi* | [**load_version**](docs/DefaultApi.md#load_version) | **POST** /versions/loadVersion | 
*DefaultApi* | [**login**](docs/DefaultApi.md#login) | **POST** /auth/login | 
*DefaultApi* | [**logout**](docs/DefaultApi.md#logout) | **POST** /auth/logout | 
*DefaultApi* | [**parse_dataset**](docs/DefaultApi.md#parse_dataset) | **POST** /datasets/parseDataset | 
*DefaultApi* | [**recover_deleted_visualizations**](docs/DefaultApi.md#recover_deleted_visualizations) | **POST** /visualizations/recoverDeletedVisualizations | 
*DefaultApi* | [**remove_dashboard**](docs/DefaultApi.md#remove_dashboard) | **POST** /dashboards/remove | 
*DefaultApi* | [**remove_project_from_dashboard**](docs/DefaultApi.md#remove_project_from_dashboard) | **POST** /dashboards/removeProjectFromDashboard | 
*DefaultApi* | [**request_trial**](docs/DefaultApi.md#request_trial) | **POST** /auth/requestTrial | 
*DefaultApi* | [**resend_activation_mail**](docs/DefaultApi.md#resend_activation_mail) | **POST** /auth/resendActivationMail | 
*DefaultApi* | [**reset_password**](docs/DefaultApi.md#reset_password) | **POST** /auth/resetPassword | 
*DefaultApi* | [**save_analyzer_layout**](docs/DefaultApi.md#save_analyzer_layout) | **POST** /visualizations/saveAnalyzerLayout | 
*DefaultApi* | [**save_custom_loss_version**](docs/DefaultApi.md#save_custom_loss_version) | **POST** /custom-loss/saveCustomLossVersion | 
*DefaultApi* | [**save_dataset_version**](docs/DefaultApi.md#save_dataset_version) | **POST** /datasets/saveDatasetVersion | 
*DefaultApi* | [**save_project**](docs/DefaultApi.md#save_project) | **POST** /projects/saveProject | 
*DefaultApi* | [**send_reset_password_mail**](docs/DefaultApi.md#send_reset_password_mail) | **POST** /auth/sendResetPasswordMail | 
*DefaultApi* | [**set_project_to_dashboard**](docs/DefaultApi.md#set_project_to_dashboard) | **POST** /dashboards/setProjectToDashboard | 
*DefaultApi* | [**set_user_metadata**](docs/DefaultApi.md#set_user_metadata) | **POST** /auth/setUserMetadata | 
*DefaultApi* | [**set_user_notifications_as_read**](docs/DefaultApi.md#set_user_notifications_as_read) | **POST** /notifications/setUserNotificationsAsRead | 
*DefaultApi* | [**signup**](docs/DefaultApi.md#signup) | **POST** /auth/signup | 
*DefaultApi* | [**terminate_job**](docs/DefaultApi.md#terminate_job) | **POST** /jobs/terminateJob | 
*DefaultApi* | [**test_custom_loss**](docs/DefaultApi.md#test_custom_loss) | **POST** /custom-loss/testCustomLoss | 
*DefaultApi* | [**test_stub**](docs/DefaultApi.md#test_stub) | **POST** /custom-loss/testStub | 
*DefaultApi* | [**trash_custom_loss**](docs/DefaultApi.md#trash_custom_loss) | **POST** /custom-loss/trashCustomLoss | 
*DefaultApi* | [**trash_dataset**](docs/DefaultApi.md#trash_dataset) | **POST** /datasets/trashDataset | 
*DefaultApi* | [**trash_project**](docs/DefaultApi.md#trash_project) | **POST** /projects/trashProject | 
*DefaultApi* | [**trash_secret_manager**](docs/DefaultApi.md#trash_secret_manager) | **POST** /secret-manager/trashSecretManager | 
*DefaultApi* | [**update_secret_manager**](docs/DefaultApi.md#update_secret_manager) | **POST** /secret-manager/updateSecretManager | 
*DefaultApi* | [**view_bucket**](docs/DefaultApi.md#view_bucket) | **POST** /buckets/viewBucket | 
*DefaultApi* | [**warmup**](docs/DefaultApi.md#warmup) | **POST** /jobs/warmup | 
*DefaultApi* | [**who_am_i**](docs/DefaultApi.md#who_am_i) | **POST** /auth/whoAmI | 


## Documentation For Models

 - [ActivationParams](docs/ActivationParams.md)
 - [AddCustomLossParams](docs/AddCustomLossParams.md)
 - [AddCustomLossResponse](docs/AddCustomLossResponse.md)
 - [AddDashboardParams](docs/AddDashboardParams.md)
 - [AddDatasetResponse](docs/AddDatasetResponse.md)
 - [AddExportModelJobParams](docs/AddExportModelJobParams.md)
 - [AddJobParams](docs/AddJobParams.md)
 - [AddSecretManagerParams](docs/AddSecretManagerParams.md)
 - [AddSecretManagerResponse](docs/AddSecretManagerResponse.md)
 - [AnalyzeGradTypeEnum](docs/AnalyzeGradTypeEnum.md)
 - [AnalyzeTypeEnum](docs/AnalyzeTypeEnum.md)
 - [AnalyzerPanelLayout](docs/AnalyzerPanelLayout.md)
 - [BasicVisualizationInfo](docs/BasicVisualizationInfo.md)
 - [CloudProvider](docs/CloudProvider.md)
 - [Clusters](docs/Clusters.md)
 - [CustomLoss](docs/CustomLoss.md)
 - [CustomLossAccess](docs/CustomLossAccess.md)
 - [CustomLossFunctions](docs/CustomLossFunctions.md)
 - [CustomLossListResponse](docs/CustomLossListResponse.md)
 - [CustomLossVersion](docs/CustomLossVersion.md)
 - [Dashboard](docs/Dashboard.md)
 - [DashboardType](docs/DashboardType.md)
 - [DataStateType](docs/DataStateType.md)
 - [DataTypeEnum](docs/DataTypeEnum.md)
 - [Dataset](docs/Dataset.md)
 - [DatasetAccess](docs/DatasetAccess.md)
 - [DatasetInputInstance](docs/DatasetInputInstance.md)
 - [DatasetInputType](docs/DatasetInputType.md)
 - [DatasetMetadata](docs/DatasetMetadata.md)
 - [DatasetMetadataInstance](docs/DatasetMetadataInstance.md)
 - [DatasetMetadataType](docs/DatasetMetadataType.md)
 - [DatasetOutputInstance](docs/DatasetOutputInstance.md)
 - [DatasetOutputType](docs/DatasetOutputType.md)
 - [DatasetParseRequestParams](docs/DatasetParseRequestParams.md)
 - [DatasetSetup](docs/DatasetSetup.md)
 - [DatasetSubsetInstance](docs/DatasetSubsetInstance.md)
 - [DatasetVersion](docs/DatasetVersion.md)
 - [DeleteVisualizationsParams](docs/DeleteVisualizationsParams.md)
 - [Demo](docs/Demo.md)
 - [DiffItem](docs/DiffItem.md)
 - [DiffViz](docs/DiffViz.md)
 - [EarlyStopParams](docs/EarlyStopParams.md)
 - [EmbeddingScatter](docs/EmbeddingScatter.md)
 - [ExportModelTypeEnum](docs/ExportModelTypeEnum.md)
 - [ExportedModelJobUi](docs/ExportedModelJobUi.md)
 - [ExternalImportModelStorage](docs/ExternalImportModelStorage.md)
 - [ExternalImportModelStorageResponse](docs/ExternalImportModelStorageResponse.md)
 - [FeatureImportance](docs/FeatureImportance.md)
 - [FeatureImportanceItem](docs/FeatureImportanceItem.md)
 - [GetBranchVersionsParams](docs/GetBranchVersionsParams.md)
 - [GetBranchVersionsResponse](docs/GetBranchVersionsResponse.md)
 - [GetBucketListParams](docs/GetBucketListParams.md)
 - [GetBucketListResponse](docs/GetBucketListResponse.md)
 - [GetCurrentProjectVersionParams](docs/GetCurrentProjectVersionParams.md)
 - [GetCurrentProjectVersionResponse](docs/GetCurrentProjectVersionResponse.md)
 - [GetCustomLossVersionParams](docs/GetCustomLossVersionParams.md)
 - [GetCustomLossVersionResponse](docs/GetCustomLossVersionResponse.md)
 - [GetDashboardsResponse](docs/GetDashboardsResponse.md)
 - [GetDatasetVersionParams](docs/GetDatasetVersionParams.md)
 - [GetDatasetVersionResponse](docs/GetDatasetVersionResponse.md)
 - [GetDatasetsResponse](docs/GetDatasetsResponse.md)
 - [GetDeletedVisualizationsParams](docs/GetDeletedVisualizationsParams.md)
 - [GetDeletedVisualizationsResponse](docs/GetDeletedVisualizationsResponse.md)
 - [GetDemosResponse](docs/GetDemosResponse.md)
 - [GetExportedModelJobsParams](docs/GetExportedModelJobsParams.md)
 - [GetExportedModelJobsResponse](docs/GetExportedModelJobsResponse.md)
 - [GetJobsParams](docs/GetJobsParams.md)
 - [GetJobsResponse](docs/GetJobsResponse.md)
 - [GetKibanaDashboardsResponse](docs/GetKibanaDashboardsResponse.md)
 - [GetLatestCustomLossVersionParams](docs/GetLatestCustomLossVersionParams.md)
 - [GetLatestCustomLossVersionResponse](docs/GetLatestCustomLossVersionResponse.md)
 - [GetLatestDatasetVersionParams](docs/GetLatestDatasetVersionParams.md)
 - [GetLatestDatasetVersionResponse](docs/GetLatestDatasetVersionResponse.md)
 - [GetModelJobsParams](docs/GetModelJobsParams.md)
 - [GetModelJobsResponse](docs/GetModelJobsResponse.md)
 - [GetModelVisualizationsParams](docs/GetModelVisualizationsParams.md)
 - [GetModelVisualizationsResponse](docs/GetModelVisualizationsResponse.md)
 - [GetNotificationsResponse](docs/GetNotificationsResponse.md)
 - [GetOrganizationJobsParams](docs/GetOrganizationJobsParams.md)
 - [GetProjectSlimVersionsResponse](docs/GetProjectSlimVersionsResponse.md)
 - [GetProjectVersionsParams](docs/GetProjectVersionsParams.md)
 - [GetProjectVersionsResponse](docs/GetProjectVersionsResponse.md)
 - [GetProjectsResponse](docs/GetProjectsResponse.md)
 - [GetSecretManagerListResponse](docs/GetSecretManagerListResponse.md)
 - [GetStoredExportedModelResourceUrlParams](docs/GetStoredExportedModelResourceUrlParams.md)
 - [GetStoredExportedModelResourceUrlResponse](docs/GetStoredExportedModelResourceUrlResponse.md)
 - [GetTrainingJobParams](docs/GetTrainingJobParams.md)
 - [GetUploadSignedUrlParams](docs/GetUploadSignedUrlParams.md)
 - [GetVisualizationParams](docs/GetVisualizationParams.md)
 - [GradsAnalysis](docs/GradsAnalysis.md)
 - [GradsItem](docs/GradsItem.md)
 - [GraphData](docs/GraphData.md)
 - [GraphViz](docs/GraphViz.md)
 - [GroundTruthItem](docs/GroundTruthItem.md)
 - [Heatmap](docs/Heatmap.md)
 - [HeatmapType](docs/HeatmapType.md)
 - [HorizontalBarData](docs/HorizontalBarData.md)
 - [HorizontalBarViz](docs/HorizontalBarViz.md)
 - [ImageData](docs/ImageData.md)
 - [ImageScatterLabel](docs/ImageScatterLabel.md)
 - [ImageViz](docs/ImageViz.md)
 - [ImportDemoProjectParams](docs/ImportDemoProjectParams.md)
 - [ImportDemoProjectResponse](docs/ImportDemoProjectResponse.md)
 - [ImportModelType](docs/ImportModelType.md)
 - [ImportNewModelParams](docs/ImportNewModelParams.md)
 - [IndicatorEnum](docs/IndicatorEnum.md)
 - [IndicatorRequest](docs/IndicatorRequest.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InputItem](docs/InputItem.md)
 - [IsTrainingJobRunningParams](docs/IsTrainingJobRunningParams.md)
 - [IsTrainingJobRunningResponse](docs/IsTrainingJobRunningResponse.md)
 - [Job](docs/Job.md)
 - [JobParams](docs/JobParams.md)
 - [JobParamsOptions](docs/JobParamsOptions.md)
 - [JobParamsOptionsParams](docs/JobParamsOptionsParams.md)
 - [JobStatus](docs/JobStatus.md)
 - [JobType](docs/JobType.md)
 - [JobTypeEnum](docs/JobTypeEnum.md)
 - [KeyLoginParams](docs/KeyLoginParams.md)
 - [KibanaDashboard](docs/KibanaDashboard.md)
 - [ListObjectsParams](docs/ListObjectsParams.md)
 - [ListObjectsResponse](docs/ListObjectsResponse.md)
 - [LoadModelParams](docs/LoadModelParams.md)
 - [LoadModelResponse](docs/LoadModelResponse.md)
 - [LoadVersionParams](docs/LoadVersionParams.md)
 - [LoadVersionResponse](docs/LoadVersionResponse.md)
 - [LoginParams](docs/LoginParams.md)
 - [Model](docs/Model.md)
 - [ModelGraph](docs/ModelGraph.md)
 - [ModelHashRequestParams](docs/ModelHashRequestParams.md)
 - [ModelPopulatedJob](docs/ModelPopulatedJob.md)
 - [ModelType](docs/ModelType.md)
 - [ModelVersionIdRequestParams](docs/ModelVersionIdRequestParams.md)
 - [ModelsResponse](docs/ModelsResponse.md)
 - [NewCustomLossVersion](docs/NewCustomLossVersion.md)
 - [NewDatasetParams](docs/NewDatasetParams.md)
 - [Notification](docs/Notification.md)
 - [PanelLayout](docs/PanelLayout.md)
 - [ParseDatasetResponse](docs/ParseDatasetResponse.md)
 - [PartialRecordTourPageTourStepDefinitionArray](docs/PartialRecordTourPageTourStepDefinitionArray.md)
 - [PlanRequest](docs/PlanRequest.md)
 - [PopExploreInfo](docs/PopExploreInfo.md)
 - [PopulationExplorationOptionsParams](docs/PopulationExplorationOptionsParams.md)
 - [PredItem](docs/PredItem.md)
 - [Project](docs/Project.md)
 - [ProjectAccess](docs/ProjectAccess.md)
 - [ProjectStatus](docs/ProjectStatus.md)
 - [RecentModelsResponse](docs/RecentModelsResponse.md)
 - [RecentOrganizationModelsRequestParams](docs/RecentOrganizationModelsRequestParams.md)
 - [RecoverVisualizationsParams](docs/RecoverVisualizationsParams.md)
 - [RecoverVisualizationsResponse](docs/RecoverVisualizationsResponse.md)
 - [RemoveDashboardParams](docs/RemoveDashboardParams.md)
 - [RemoveProjectFromDashboardParams](docs/RemoveProjectFromDashboardParams.md)
 - [RequestTrialMetadata](docs/RequestTrialMetadata.md)
 - [RequestTrialParams](docs/RequestTrialParams.md)
 - [RequestTrialResponse](docs/RequestTrialResponse.md)
 - [ResendActivationMailParams](docs/ResendActivationMailParams.md)
 - [ResendActivationMailResponse](docs/ResendActivationMailResponse.md)
 - [ResetPasswordParams](docs/ResetPasswordParams.md)
 - [ResetPasswordResponse](docs/ResetPasswordResponse.md)
 - [SampleAnalysisViz](docs/SampleAnalysisViz.md)
 - [SampleIdentity](docs/SampleIdentity.md)
 - [SampleSelectionInfo](docs/SampleSelectionInfo.md)
 - [SampleSelectionOptionsParams](docs/SampleSelectionOptionsParams.md)
 - [SampleVisualizationInfo](docs/SampleVisualizationInfo.md)
 - [SaveAnalyzerLayoutParams](docs/SaveAnalyzerLayoutParams.md)
 - [SaveCustomLossVersionParams](docs/SaveCustomLossVersionParams.md)
 - [SaveCustomLossVersionResponse](docs/SaveCustomLossVersionResponse.md)
 - [SaveDatasetSetupResponse](docs/SaveDatasetSetupResponse.md)
 - [SaveDatasetVersionParams](docs/SaveDatasetVersionParams.md)
 - [SaveProjectParams](docs/SaveProjectParams.md)
 - [SaveProjectResponse](docs/SaveProjectResponse.md)
 - [ScatterLabel](docs/ScatterLabel.md)
 - [ScatterViz](docs/ScatterViz.md)
 - [ScatterVizDataState](docs/ScatterVizDataState.md)
 - [ScheduleRequest](docs/ScheduleRequest.md)
 - [SecretManager](docs/SecretManager.md)
 - [SendResetPasswordMailParams](docs/SendResetPasswordMailParams.md)
 - [SendResetPasswordMailResponse](docs/SendResetPasswordMailResponse.md)
 - [SetProjectToDashboardParams](docs/SetProjectToDashboardParams.md)
 - [SetUserMetadataInnerParams](docs/SetUserMetadataInnerParams.md)
 - [SetUserMetadataParams](docs/SetUserMetadataParams.md)
 - [SetUserMetadataResponse](docs/SetUserMetadataResponse.md)
 - [SignupParams](docs/SignupParams.md)
 - [SignupResponse](docs/SignupResponse.md)
 - [SlimVersion](docs/SlimVersion.md)
 - [SlimVisualization](docs/SlimVisualization.md)
 - [StepType](docs/StepType.md)
 - [StripType](docs/StripType.md)
 - [TerminateJobParams](docs/TerminateJobParams.md)
 - [TerminateJobResponse](docs/TerminateJobResponse.md)
 - [TestCustomLossParams](docs/TestCustomLossParams.md)
 - [TestCustomLossResponse](docs/TestCustomLossResponse.md)
 - [TestStatus](docs/TestStatus.md)
 - [TestStubParams](docs/TestStubParams.md)
 - [TestStubResponse](docs/TestStubResponse.md)
 - [TextData](docs/TextData.md)
 - [TextScatterLabel](docs/TextScatterLabel.md)
 - [TextViz](docs/TextViz.md)
 - [TourStepDefinition](docs/TourStepDefinition.md)
 - [TrainingParams](docs/TrainingParams.md)
 - [TrashCustomLossParams](docs/TrashCustomLossParams.md)
 - [TrashDatasetParams](docs/TrashDatasetParams.md)
 - [TrashProjectParams](docs/TrashProjectParams.md)
 - [TrashSecretManagerParams](docs/TrashSecretManagerParams.md)
 - [TrashSecretManagerResponse](docs/TrashSecretManagerResponse.md)
 - [UiFuncInstance](docs/UiFuncInstance.md)
 - [UpdateSecretManagerParams](docs/UpdateSecretManagerParams.md)
 - [UpdateSecretManagerResponse](docs/UpdateSecretManagerResponse.md)
 - [UserData](docs/UserData.md)
 - [UserDataLocal](docs/UserDataLocal.md)
 - [UserDataMetadata](docs/UserDataMetadata.md)
 - [UserRole](docs/UserRole.md)
 - [Version](docs/Version.md)
 - [VisData](docs/VisData.md)
 - [Visualization](docs/Visualization.md)
 - [VisualizationData](docs/VisualizationData.md)
 - [VisualizationResponse](docs/VisualizationResponse.md)
 - [VisualizationTarget](docs/VisualizationTarget.md)
 - [VisualizationTargetType](docs/VisualizationTargetType.md)
 - [VizInfoType](docs/VizInfoType.md)
 - [VizType](docs/VizType.md)
 - [WordData](docs/WordData.md)
 - [WordScatterLabel](docs/WordScatterLabel.md)
 - [WordViz](docs/WordViz.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author




## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in openapi_client.apis and openapi_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from openapi_client.api.default_api import DefaultApi`
- `from openapi_client.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import openapi_client
from openapi_client.apis import *
from openapi_client.models import *
```

